import { Place } from '../../lib/sdk';
import { E_DEPARTURE_MODE } from '../../lib/types/directions';
import { E_APP_STATE } from '../../lib/types/state';
export type Transient<T> = {
    [K in keyof T as K extends `$${string}` ? K : `$${K & string}`]: T[K];
};
export type Untrasient<T> = {
    [K in keyof T as K extends `$${infer R}` ? R : K]: T[K];
};
/**
 * Ensures a props object contains entirely transient keys for styled-components.
 */
export declare const transient: <T extends Record<string, unknown>>(obj: T) => Transient<T>;
export declare const id: (...values: string[]) => string;
export type TFocusOutlineOptions = {
    $outlineOffset?: number;
    $outlineColor?: string;
    $outlineWidth?: number;
};
export declare const focusOutline: import("styled-components").RuleSet<TFocusOutlineOptions>;
type TGenerateGlobalClassNamesOptions = {
    state: E_APP_STATE;
    selectedPlaces: Place[];
    departures: Place[];
    droppedPinHoverVisible: boolean;
    darkMode: boolean;
    departureMode: E_DEPARTURE_MODE;
    safetyMode: boolean;
};
export declare const generateGlobalClassNames: ({ state, selectedPlaces, departures, droppedPinHoverVisible, darkMode, departureMode, safetyMode, }: TGenerateGlobalClassNamesOptions) => string;
/**
 * Low level utility to generate class name selectors. Do not use this directly.
 */
export declare const andClassNames: (classNames: string[]) => string;
/**
 * Low level utility to generate class name selectors. Do not use this directly.
 */
export declare const orClassNames: (classNames: string[]) => string;
/**
 * A utility function returning css that only applies when the provided {@link Place} is selected. Requires
 * {@link generateGlobalClassNames} to be used to apply the correct class names to the root element.
 *
 * @example
 * ```tsx
 * const MyComponent = styled.div<{ place: Place }>`
 * 	// Change the background color when "place" is selected
 * 	${({place}) => isSelected(place)`
 * 		background-color: red;
 * 	`}
 * `;
 * ```
 */
export declare const isSelected: (place: Place) => ((...args: any) => string);
/**
 * A utility function returning css that only applies when the provided {@link Place} is a departure. Requires
 * {@link generateGlobalClassNames} to be used to apply the correct class names to the root element.
 *
 * @example
 * ```tsx
 * const MyComponent = styled.div<{ place: Place }>`
 * 	// Change the background color when "place" is a departure
 * 	${({place}) => isDeparture(place)`
 * 		background-color: red;
 * 	`}
 * `;
 * ```
 */
export declare const isDeparture: (place: Place) => ((...args: any) => string);
/**
 * A utility function returning css that only applies when the app is in the provided {@link E_APP_STATE}. Requires
 * {@link generateGlobalClassNames} to be used to apply the correct class names to the root element.
 *
 * @example
 * ```tsx
 * const MyComponent = styled.div`
 * 	// Change the background color when the app is in the "DIRECTIONS" state
 * 	${isState(E_APP_STATE.DIRECTIONS)`
 * 		background-color: red;
 * 	`}
 * `;
 * ```
 */
export declare const isState: (state: E_APP_STATE) => ((...args: any) => string);
/**
 * A utility function returning css that only applies when the dropped pin hover is visible. Requires
 * {@link generateGlobalClassNames} to be used to apply the correct class names to the root element.
 *
 * @example
 * ```tsx
 * const MyComponent = styled.div`
 * 	// Change the background color when the dropped pin hover is visible
 * 	${isDroppedPinHoverVisible(true)`
 * 		background-color: red;
 * 	`}
 */
export declare const isDroppedPinHoverVisible: (visible: boolean) => ((...args: any) => string);
/**
 * A utility function returning css that only applies when the app is in dark mode. Requires
 * {@link generateGlobalClassNames} to be used to apply the correct class names to the root element.
 *
 * @example
 * ```tsx
 * const MyComponent = styled.div`
 * 	// Change the background color when the app is in dark mode
 * 	${isDarkMode(true)`
 * 		background-color: black;
 * 	`}
 * `;
 * ```
 */
export declare const isDarkMode: (darkMode: boolean) => ((...args: any) => string);
/**
 * A utility function returning css that only applies when the provided {@link E_DEPARTURE_MODE} is active. Requires
 * {@link generateGlobalClassNames} to be used to apply the correct class names to the root element.
 *
 * @example
 * ```tsx
 * const MyComponent = styled.div`
 * 	// Change the background color when the app is in "NEAREST_ENTRANCE" departure mode
 * 	${isDepartureMode(E_DEPARTURE_MODE.NEAREST_ENTRANCE)`
 * 		background-color: black;
 * 	`}
 * `;
 * ```
 */
export declare const isDepartureMode: (mode: E_DEPARTURE_MODE) => ((...args: any) => string);
/**
 * A utility function returning css that only applies when the safety mode is enabled. Requires
 * {@link generateGlobalClassNames} to be used to apply the correct class names to the root element.
 */
export declare const isSafetyMode: (safetyMode: boolean) => ((...args: any) => string);
export {};
