import { ComponentProps } from 'react';
import { TOnClickOrPressPayload } from '../button';
import SocialsItem from '../socials-item';
import OpeningHours from '../../lib/time/opening-hours';
import ReactDOM from 'react-dom/client';
import { TSocials } from '../../lib/types/socials';
export declare const METADATA_CARD_WIDTH = 320;
export declare const METADATA_CARD_PADDING = 20;
export declare const HERO_IMAGE_HEIGHT = 200;
export type TMetadataCardProps = {
    /**
     * The name of the place.
     */
    name?: string;
    /**
     * Logo image URL.
     */
    logoImage?: string;
    /**
     * A description of the place.
     */
    description?: string;
    /**
     * Main website URL.
     */
    website?: {
        url: string;
        name?: string;
    };
    /**
     * Other URLs to show. Links can optionally be named. Unnamed links will show up as the link URL.
     */
    links?: {
        url: string;
        name?: string;
    }[];
    /**
     * Phone number to show.
     */
    phoneNumber?: string;
    /**
     * Social media URLs to show.
     */
    socialUrls?: ComponentProps<typeof SocialsItem>['socialUrls'];
    /**
     * Image URLs to show in the hero gallery at the top of the card.
     */
    heroImages?: string[];
    /**
     * Categories to show in the card.
     */
    categories?: {
        id: string;
        name: string;
    }[];
    /**
     * Opening hours to show in the card.
     */
    hours?: OpeningHours;
    /**
     * URL to show on a button just above the directions button.
     */
    footerLink?: {
        url: string;
        name?: string;
    };
    /**
     * Callback when the close button is clicked.
     */
    onClose?: () => void;
    /**
     * Callback when the directions button is clicked.
     */
    onDirectionsClick?: (e: TOnClickOrPressPayload) => void;
    /**
     * Callback when the full screen gallery is opened.
     */
    onFullScreenGalleryOpen?: () => void;
    /**
     * Callback when a link is clicked. The link itself will open by default in a new tab. This
     * callback can be used to handle an extra functionality, e.g. analytics.
     */
    onLinkClick?: (url: string) => void;
    /**
     * Callback when the location link is clicked to copy a deep link to the location.
     */
    onCopyLocationLink?: () => void;
    /**
     * Callback when a category is clicked.
     */
    onCategoryClick?: (category: string) => void;
    /**
     * Callback when a social URL is clicked. The social URL will open by default in a new tab. This
     * callback can be used to handle an extra functionality, e.g. analytics.
     */
    onSocialClick?: (social: TSocials) => void;
    /**
     * Callback when the website URL is clicked. The website URL will open by default in a new tab. This
     * callback can be used to handle an extra functionality, e.g. analytics.
     */
    onWebsiteClick?: () => void;
    /**
     * Callback when the phone number is clicked. The phone number will open by default. This callback
     * can be used to handle an extra functionality, e.g. analytics.
     */
    onPhoneNumberClick?: () => void;
    /**
     * Callback when the link button is clicked. The link button will open by default in a new tab. This
     * callback can be used to handle an extra functionality, e.g. analytics.
     */
    onLinkButtonClick?: () => void;
    /**
     * Optionally disable the directions button.
     */
    directionsButtonDisabled?: boolean;
    /**
     * Whether to use the image proxy to resize the images, defaults to true.
     */
    proxyImages?: boolean;
};
export declare const useMetadataCard: (options: TMetadataCardProps) => {
    heroImageURLs: (Pick<string[], 0> & string[]) | null;
    categoriesList: (Pick<{
        id: string;
        name: string;
    }[], 0> & {
        id: string;
        name: string;
    }[]) | null;
};
/**
 * Imperative API to render the viewer's metadata card into a provided container element.
 */
export declare const showViewerCard: (container: Element, props: TMetadataCardProps) => ReactDOM.Root;
/**
 * A React component that renders the viewer's metadata card with a theme provider so it can
 * be used externally.
 */
export declare const ViewerCard: React.FC<TMetadataCardProps>;
