import { E_DEPARTURE_MODE } from '../types/directions';
type TUpdateUIStateFn = (state: Partial<TUIBaseState>) => void;
declare const BASE_STATE: {
    isDirectionsSearchBarFocused: boolean;
};
/**
 * The UI state variables that can be set or initialized.
 */
type TUIBaseState = typeof BASE_STATE;
/**
 * The UI state that comes from external dependencies, i.e. the MobX stores.
 */
export type TUIStateDependencies = {
    departureMode: E_DEPARTURE_MODE | undefined;
    directionsVisible: boolean;
    directionsWarningTranslationKey: string | undefined;
};
/**
 * The raw state passed down by the context provider.
 */
type TUIStateContext = TUIBaseState & TUIStateDependencies & {
    update: TUpdateUIStateFn;
};
/**
 * Styling related state that needs to be passed around easily between components. This should
 * not contain state that is necessary to perform any application logic, only state that affects
 * styling. Logic should be handled in the MobX stores.
 */
export declare const UIState: import("react").Context<TUIStateContext>;
/**
 * Hook to create a new UI state object. Call this only in the top level component.
 */
export declare const useCreateUIState: (dependencies: TUIStateDependencies) => readonly [{
    isDirectionsSearchBarFocused: boolean;
    departureMode: E_DEPARTURE_MODE | undefined;
    directionsVisible: boolean;
    directionsWarningTranslationKey: string | undefined;
}, import("react").Dispatch<Partial<{
    isDirectionsSearchBarFocused: boolean;
}>>];
/**
 * Hook to read and update the current UI state.
 */
export declare const useUIState: () => readonly [{
    isDirectionsSearchResultsVisible: boolean;
    isDirectionsSearchBarVisible: boolean;
    isDirectionsWarningVisible: boolean;
    isDirectionsSearchBarFocused: boolean;
    departureMode: E_DEPARTURE_MODE | undefined;
    directionsVisible: boolean;
    directionsWarningTranslationKey: string | undefined;
}, TUpdateUIStateFn];
export {};
