import type { MapView, TEvents as SDKEvents } from './mappedin-js';
import type { TEventPayload } from './types';
/**
 * Asynchronously subscribe to events from a map view that may not exist yet, and override map view
 * events with custom behaviour.
 */
declare class MapViewEvents<Overrides extends {
    [event in keyof SDKEvents]?: unknown;
} = Record<string, never>> {
    private pendingEventDisposers;
    private mapView;
    private customEventNames;
    private customEvents;
    constructor(overrides?: {
        [event in keyof Overrides]?: {
            transformer: (payload: event extends keyof SDKEvents ? TEventPayload<event> : never) => Overrides[event];
        };
    });
    private isCustomEvent;
    private addPendingSDKEvent;
    private cancelPendingSDKEvent;
    private subscribeSDKEvent;
    private unsubscribeSDKEvent;
    setMapView(mapView: MapView): void;
    on<T extends (keyof SDKEvents | keyof Overrides) & string>(event: T, handler: (payload: T extends keyof Overrides ? Overrides[T] : T extends keyof SDKEvents ? SDKEvents[T] : never) => void): void;
    off<T extends (keyof SDKEvents | keyof Overrides) & string>(event: T, handler: (payload: T extends keyof Overrides ? Overrides[T] : T extends keyof SDKEvents ? SDKEvents[T] : never) => void): void;
    destroy(): void;
}
export default MapViewEvents;
