import { StyleCollection } from '@mappedin/mvf';
import { TStyleOverride, TTheme } from '../types/theme';
import { DeepPartial } from '../types/utils';
export type TThemeVariant = DeepPartial<TTheme> & {
    name: string;
};
/**
 * When testing new themes, we want to give ourselves some time to tweak them after they
 * are released. If we bake the themes into MVF right away, we can't update the themes
 * without republishing the MVFs.
 *
 * Creating map style variants in the viewer allows us to test new themes without commiting
 * them to the MVF yet. After a theme is stable, it should be added to the MVF.
 */
export declare const createMapStyles: (options: {
    tiles: string;
    wallColor: string;
    roomColor: string;
    inaccessibleRoomColor: string;
    hallwayColor: string;
    bathroomColor: string;
    deskColor: string;
    facadeColor: string;
}) => Pick<TTheme["map"], "tiles" | "mvfOverrides">;
export declare const getTilesUrl: (name: string) => string;
/**
 * Given a set of styles and a set of overrides, return a complete set of styles that includes
 * the overrides applied and references all the same geometries.
 */
export declare const styleCollection: (base: StyleCollection, overrides: TStyleOverride) => StyleCollection;
