import Time from './time';
import { TOpeningHours } from './types';
/**
 * Class with a time and day of the week.
 */
declare class TimeOfWeek {
    #private;
    constructor(time: Time, day: number);
    get day(): number;
    get time(): Time;
    toLocaleString(locale: string, options?: Partial<{
        includeDay: boolean;
    }>): string;
}
/**
 * A set of opening hours for a location defined in local time within a specific timezone.
 */
declare class OpeningHours {
    #private;
    /**
     * Create a new OpeningHours object.
     */
    constructor(openingHours: TOpeningHours, tz: string);
    /**
     * Return a {@link Time} object in the store's timezone. Defaults to the current date.
     */
    getTime(date?: Date): Time;
    /**
     * Return a day of the week as a number in the store's timezone. Defaults to the current date.
     */
    getDay(date?: Date): number;
    /**
     * Return an array of localized, formatted string representations of the opening hours for each
     * day of the week. The first entry in the array is the provided date's opening hours. If no
     * date is provided, the current date is used.
     */
    toLocaleStrings(locale: string, date?: Date): (readonly [string, string])[];
    /**
     * Return true if the opening hours are open 24/7.
     */
    isOpen247(): boolean;
    /**
     * Return true if the opening hours are always closed.
     */
    isClosed247(): boolean;
    /**
     * Returns true if a given {@link Date} is within the opening hours. Defaults to checking the
     * current date.
     */
    isOpen(date?: Date): boolean;
    /**
     * Return true if a given {@link Date} is within 1 hour of the opening hours. Returns false if
     * the store is already open. Defaults to checking the current date.
     */
    isOpeningSoon(date?: Date): boolean;
    /**
     * Return true if a given {@link Date} is within 1 hour of the closing hours. Returns false if
     * the store is already closed. Defaults to checking the current date.
     */
    isClosingSoon(date?: Date): boolean;
    /**
     * Returns the next time the store will open from a given date. Defaults to checking the current
     * date.
     */
    opensAt(date?: Date): TimeOfWeek | null;
    /**
     * Returns the next time the store will close from a given date. Defaults to checking the current
     * date.
     */
    closesAt(date?: Date): TimeOfWeek | null;
}
export default OpeningHours;
