declare const customInspectSymbol: unique symbol;
/**
 * A time in minutes and hours, without a date.
 */
declare class Time {
    #private;
    /**
     * Create a new Time object. If no arguments are provided, the current time is used.
     * If a Date is provided, the time is set to the time of the provided date. If two
     * numbers are provided, the time is set to the given hours and minutes.
     */
    constructor();
    constructor(date: Date);
    constructor(hour: number, minute: number);
    /**
     * Get the hours of this time.
     */
    get hours(): number;
    /**
     * Get the minutes of this time.
     */
    get minutes(): number;
    [customInspectSymbol](): string;
    /**
     * Returns true if this time is midnight. This can be either 00:00 or 24:00.
     */
    isMidnight(): boolean;
    /**
     * Returns true if this time is noon.
     */
    isNoon(): boolean;
    /**
     * Returns true if this time is equal to another time. 00:00 and 24:00 are considered
     * to be equal.
     */
    isEqual(other: Time): boolean;
    /**
     * Returns true if this time is later than another time, assuming the times are on the
     * same day. 00:00 is considered to be earlier than any other time; 24:00 is considered
     * to be later than any other time.
     */
    isLaterThan(other: Time): boolean;
    /**
     * Returns true if this time is later than or equal to another time. Unlike {@link isLaterThan},
     * 00:00 is considered to be equal to 24:00.
     */
    isLaterThanOrEqual(other: Time): boolean;
    /**
     * Returns true if the given time is between the start and end time, inclusive.
     *
     * Assumes the start time is on the same day. If the end time is earlier than the start time,
     * it is assumed to be on the next day. If the start time is equal to the end time, it is
     * assumed to include the entire day and this function will always return true.
     */
    isBetween(start: Time, end: Time): boolean;
    /**
     * Return the number of minutes forward in time required to reach another time. If the
     * other time is earlier than this time, it is assumed to be on the next day.
     */
    minutesTo(other: Time): number;
    /**
     * Return a localized, formatted string representation of the time.
     */
    toLocaleString(locale?: string, options?: Intl.DateTimeFormatOptions): string;
}
export default Time;
