/**
 * An array representing a time range in hours and minutes. If the second time is earlier
 * than the first time, it is assumed to be on the next day.
 */
export type TTimeRange = [number, number, number, number];
/**
 * Opening hours for a single day. For a store with hours, it is either a {@link TTimeRange}
 * or a pair of {@link TTimeRange}s, or null if the store is closed for the day. The second
 * time range, if specified, must begin after the first time range ends. Otherwise, the meaning
 * is undefined.
 */
export type TSingleDayOpeningHours = [TTimeRange] | [TTimeRange, TTimeRange] | null;
/**
 * A collection of {@link TSingleDayOpeningHours} for Sunday to Saturday.
 */
export type TRegularOpeningHours = [
    TSingleDayOpeningHours,
    TSingleDayOpeningHours,
    TSingleDayOpeningHours,
    TSingleDayOpeningHours,
    TSingleDayOpeningHours,
    TSingleDayOpeningHours,
    TSingleDayOpeningHours
];
/**
 * A collection of {@link TSingleDayOpeningHours} for every day of the week and for
 * holidays. The first entry is for Sunday, the second for Monday, etc. The last entry
 * is for holidays.
 */
export type TOpeningHours = TRegularOpeningHours | [
    ...TRegularOpeningHours,
    TSingleDayOpeningHours
];
