import Time from './time';
import { TSingleDayOpeningHours, TTimeRange } from './types';
/**
 * Returns true if the given locale uses a 24-hour time format.
 */
export declare const is24HourTime: (locale: string) => boolean;
/**
 * Convert the name of a day of the week to a number between 0 and 6. Returns -1 if the day is not
 * valid.
 */
export declare const dayOfWeekNum: (day: string) => number;
/**
 * Get the current timezone of the client.
 */
export declare const getTZ: () => string;
/**
 * Given a timezone and a date, return the hours, minutes, and day of week in that timezone.
 * Day of week is 0-6, where 0 is Sunday. If no timezone is specified, uses the client's local
 * timezone. If no date is specified, uses the current date.
 */
export declare const getTimePartsAtTZ: (tz: string, date: Date) => {
    hours: number;
    minutes: number;
    dayOfWeek: number;
};
/**
 * Given a single day's opening hours, return the start and end times. If the opening
 * hours are a pair of time ranges, return the start and end times for both ranges.
 * Returns null if the store is closed for the day.
 */
export declare function singleDayOpeningHoursTimes(hours: null): null;
export declare function singleDayOpeningHoursTimes(hours: [TTimeRange]): [Time, Time];
export declare function singleDayOpeningHoursTimes(hours: [TTimeRange, TTimeRange]): [Time, Time, Time, Time];
export declare function singleDayOpeningHoursTimes(hours: TSingleDayOpeningHours): [Time, Time] | [Time, Time, Time, Time] | null;
/**
 * Parse a time string in the format of 'HH:MM' into hours and minutes.
 */
export declare const parseTimeString: (time: string) => {
    hours: number;
    minutes: number;
};
