import { StyleCollection } from '@mappedin/mvf';
import { DeepPartial } from './utils';
type Styles = Exclude<StyleCollection[string], undefined>;
type StylesWithColor = Extract<Styles, {
    color: unknown;
}>;
export type TStyleOverride = {
    [groupId: string]: {
        color: StylesWithColor['color'];
    };
};
export type TTheme = {
    name: string;
    isDark: boolean;
    colors: {
        accent: {
            primary: string;
            secondary: string;
            neutral: string;
            neutral2: string;
            success: string;
            error: string;
        };
        background: {
            primary: string;
            secondary: string;
            tertiary: string;
            inverted: string;
        };
        text: {
            primary: string;
            secondary: string;
            tertiary: string;
            quaternary: string;
            highlight: string;
            placeholder: string;
            inverted: string;
            link: string;
            error: string;
            error2: string;
        };
        map: {
            labels: {
                background: string;
                default: string;
                connection: string;
                washroom: string;
                parking: string;
                point: string;
                door: string;
            };
            markers: {
                text: string;
                icon: string;
                background: string;
                default: string;
                parachute: string;
                highlight: string;
                departure: string;
                destination: string;
                youAreHere: string;
            };
            geometry: {
                wallTops: string;
                departure: string;
                hover: string;
                highlight: string;
            };
            path: string;
            background: string;
        };
    };
    font: string;
    borderRadius: {
        primary: number;
        large: number;
        small: number;
    };
    fontSize: {
        xsmall: number;
        small: number;
        normal: number;
        large: number;
        xlarge: number;
        title: number;
    };
    fontWeight: {
        light: number;
        normal: number;
        medium: number;
        semiBold: number;
        bold: number;
    };
    map: {
        tiles: string;
        initialPitch: number;
        initialBearing: number;
        minZoom: number;
        maxZoom: number;
        pathSize: number;
        streetMapVisible: boolean;
        watermarkVisible: boolean;
        mvfOverrides: TStyleOverride;
    };
};
export type TThemeOverride = DeepPartial<TTheme> | number;
export {};
