export declare const DEFAULT_ANIMATION_DURATION_MS = 175;
export declare let ANIMATION_DURATION_MS: number;
export declare const setAnimationDuration: (duration: number) => void;
export declare const SCHEDULER_TIMEOUT_MS = 500;
/**
 * Simple class to help with scheduling expensive functions against high priority
 * UI animations.
 */
declare class AnimationScheduler {
    private scheduledFunctions;
    private highPriorityAnimations;
    private flushFunctions;
    /**
     * Indicate than an animation is beginning.
     */
    begin(animationName: string): void;
    /**
     * Indicate that an animation has ended.
     */
    end(animationName: string): void;
    /**
     * Whether or not there are any animations currently running.
     */
    isAnimating(): boolean;
    /**
     * Schedule a function to run after any currently running animations have ended. If the
     * function has not been called after a certain timeout, it will be called anyway.
     */
    defer(fn: () => void): void;
    cleanup(): void;
}
/**
 * {@link AnimationScheduler} instance to be used throughout the application.
 */
export declare const animationScheduler: AnimationScheduler;
export declare const getTransitionPropsForTaskScheduler: (animationName: string, options?: {
    debug?: boolean;
}) => {
    onEnter: () => void;
    onEntered: () => void;
    onExit: () => void;
    onExited: () => void;
};
export {};
