import { Annotation, Place, Coordinate, TNavigationTarget, Floor, LocationProfile, IFocusable } from '../sdk';
import OpeningHours from '../time/opening-hours';
/**
 * Whether the location can be assumed to be a washroom
 */
export declare const isWashroom: (place: Place) => any;
/**
 * Whether the location can be assumed to be a parking spot
 */
export declare const isParking: (place: Place) => any;
/**
 * Whether the location has a name
 */
export declare const hasName: (place: Place) => boolean;
/**
 * Whether the location has any metadata other than name
 */
export declare const hasMetaData: (place: Place) => boolean;
export declare const hasLocationProfiles: (place: Place) => boolean;
/**
 * Whether the location has a name or any other metadata
 */
export declare const hasNameOrMetaData: (place: Place) => boolean;
export declare const getCategoryName: (place: Place) => string;
export declare const getAnnotationName: (annotation: Annotation) => string;
export type TGetDisplayNameForPlaceOptions = {
    fallbackToCategoryName?: boolean;
};
/**
 * For a location, return a name that is as specific as we can be. Use {@link UIStore.getDisplayName} when possible.
 */
export declare const getDisplayNameForPlace: (place: Place, options?: TGetDisplayNameForPlaceOptions) => string;
/**
 * For a list of locations, return a generic name that is as specific as we can be. Use {@link UIStore.getDisplayName}
 * when possible.
 */
export declare const getDisplayNameForPlaces: (places: Place[]) => string;
/**
 * Check if a place has data we can reasonably believe to be valid. We can assume any coordinate
 * that is close to 0,0 is the result of some sort of invalid data.
 */
export declare const isValidPlace: (place: Place) => boolean;
/**
 * Abstraction for getting navigation target for places. Any place should technically be fine to use
 * as a navigation target, but sometimes the SDK types are stale, and sometimes certain behaviours
 * yield better results.
 */
export declare const getNavigationTargetForPlaces: (places: Place[]) => TNavigationTarget | TNavigationTarget[];
/**
 * Abstraction for getting camera targets for places. Any place should technically be fine to use
 * as a camera target, but sometimes the SDK types are stale, and sometimes certain behaviours
 * yield better results.
 */
export declare const getCameraTargetsForPlaces: (places: Floor | Place | Place[] | IFocusable | IFocusable[]) => any[] | IFocusable;
export declare const getSearchIdForPlace: (place: Place) => string | undefined;
export declare const getFloors: (place: Exclude<Place, Coordinate>) => Floor[];
export declare const getPlacesForLocation: (location: LocationProfile) => Exclude<Place, LocationProfile | Coordinate>[];
export declare const getLocationsForPlace: (place: Place) => LocationProfile[];
/**
 * Check if a place is on a floor.
 */
export declare const isOnFloor: (place: Place, floor: Floor | string | undefined) => boolean;
/**
 * Convert the opening hours format from the SDK to a format the viewer wants to render.
 */
export declare const convertHours: (hours: LocationProfile["openingHours"], tz?: string) => OpeningHours;
