export declare const BG_FOR_DARK_IMAGE = "#FFFFFF";
export declare const BG_FOR_LIGHT_IMAGE = "#333333";
/**
 * Utility to bust the image caches. Mostly meant for unit testing.
 */
export declare const cleanup: () => void;
/**
 * Get the top left pixel color of an image.
 */
export declare const extractTopLeftPixelColor: (src: string) => Promise<string>;
/**
 * @deprecated Use {@link approxAveragePixelColor} instead. This function should only be used for benchmarking.
 *
 * Get the average pixel color of an image. Semi-transparent pixels are weighted proportionally
 * with fully transparent pixels being ignored.
 */
export declare const getAveragePixelColor: (src: string, options?: Partial<{
    debug: boolean;
}>) => Promise<string>;
/**
 * A faster version of {@link getAveragePixelColor} that relies on the browser to shrink the image down before
 * processing its colors.
 */
export declare const approxAveragePixelColor: (src: string, options?: Partial<{
    debug: boolean;
    /**
     * The resolution to transform the image to before processing. Higher resolutions will lead to better accuracy.
     * Lower resolutions will yield faster processing. Going too low may lead to inconsistent results with transparent
     * pixels.
     */
    resolution: number;
}>) => Promise<string>;
export declare const IMAGE_SIZE: {
    readonly xsmall: 64;
    readonly small: 256;
    readonly medium: 512;
};
export type TImageSize = keyof typeof IMAGE_SIZE | 'fit-window';
export type TImageFit = 'fill' | 'fit';
/**
 * Generate a new URL for an image resized to within a square of the specified dimension.
 */
export declare const resizedImageSrc: (src: string, size: TImageSize, options?: Partial<{
    fit: "fill" | "fit";
}>) => string;
