import { KeysOf } from '../types/utils';
type ArrayKeys<T> = KeysOf<T, Array<unknown>>;
type ArrayValues<T> = Required<T>[ArrayKeys<T>] extends Array<infer U> ? U : never;
/**
 * Push a value to an array property of an object, creating the array if it doesn't exist.
 */
export declare const safePush: <T extends object>(object: T, key: ArrayKeys<T>, value: ArrayValues<T>) => void;
type SetKeys<T> = KeysOf<T, Set<unknown>>;
type SetValues<T> = Required<T>[SetKeys<T>] extends Set<infer U> ? U : never;
/**
 * Add a value to a set property of an object, creating the set if it doesn't exist.
 */
export declare const safeAdd: <T extends object>(object: T, key: SetKeys<T>, value: SetValues<T>) => void;
/**
 * Whether the object has an array property with a length greater than 0.
 */
export declare const hasArray: <T extends object>(object: T, key: string) => boolean;
/**
 * Whether the object has a string property with a length greater than 0.
 */
export declare const hasString: <T extends object>(object: T, key: string) => boolean;
export {};
