import { type PostHog } from 'posthog-js';
import type { TAnalyticsEvent, TCaptureParams } from '../../stores/analytics-store';
/**
 * We allow setting an external posthog instance to be used by the viewer. This is mostly
 * to support Maker, which has its own posthog instance.
 */
export declare const setPosthog: (posthog: PostHog) => void;
/**
 * Get the current posthog instance. This should be used over importing the posthog-js, since
 * an external posthog instance may have been set.
 */
export declare const getPosthog: () => PostHog;
/**
 * Check if the current posthog instance is the default instance.
 */
export declare const isDefaultPosthogInstance: () => boolean;
/**
 * Control whether or not events are captured.
 */
export declare const enableCapture: (enabled: boolean) => void;
/**
 * Check if events are currently being captured.
 */
export declare const isCaptureEnabled: () => boolean;
/**
 * Capture a posthog event.
 *
 * Note: this should only be used as a last resort if stores are not available. Otherwise, use
 * the {@link AnalyticsStore} to capture events.
 */
export declare const capture: <E extends TAnalyticsEvent>(...args: TCaptureParams<E>) => void;
/**
 * Initialize a posthog instance for the whole application.
 */
export declare const initPosthog: (options?: Partial<{
    autocapture: boolean;
    isMakerPreview: boolean;
    captureEnabled: boolean;
    mapId: string;
    configId: string;
}>) => void;
