import { Area, Coordinate, Floor, Geometry, LocationCategory, MapData, Place, PlaceTypeString } from '../sdk';
import rbush from '@turf/geojson-rbush';
import { GeoJsonProperties, Point, Polygon, Geometry as GeoJSONGeometry } from 'geojson';
type RBush<G extends GeoJSONGeometry, P extends GeoJsonProperties> = ReturnType<typeof rbush<G, P>>;
type TLookupProperties = {
    id: string;
    type: PlaceTypeString;
};
type TProcessedPlaces = {
    places: Exclude<Place, Coordinate>[];
    placesById: Record<string, Exclude<Place, Coordinate>>;
    placesByName: Record<string, Exclude<Place, Coordinate>[]>;
    placesByNameNormalized: Record<string, Exclude<Place, Coordinate>[]>;
    placesByFloorId: Record<string, Exclude<Place, Coordinate>[]>;
    areasByFloorId: Record<string, Area[]>;
    placesWithMetadata: Exclude<Place, Coordinate>[];
    placeNamesByCategory: Record<string, string[]>;
    geometries: Geometry[];
    geometriesById: Record<string, Geometry>;
    sortedPlaceNames: string[];
    floorsByNameNormalized: Record<string, Floor>;
    categoriesByNameNormalized: Record<string, LocationCategory>;
    rbushByFloorId: Record<string, RBush<Point | Polygon, TLookupProperties>>;
};
/**
 * Generate a bunch of useful immutable collections from the map data.
 */
export declare const processPlaces: (data: MapData) => TProcessedPlaces;
export {};
