export declare const STORAGE_LIFETIME: {
    ONE_DAY: number;
    ONE_WEEK: number;
    ONE_MONTH: number;
    ONE_YEAR: number;
};
export declare enum STORAGE_KEY {
    MAKER_POP_UP_DISMISSED = "maker-pop-up-dismissed"
}
/**
 * Saves data to the browser's local storage.
 *
 * @param key Ideally a unique key for retrieving stored data later.
 * @param data The data to be saved. This should be JSON-serializable
 * so it is compatible with localStorage, which expects string data.
 * @param lifespan How long this data should be considered valid,
 * in seconds. This should only be a safe, positive integer value.
 * @returns true if the data was successfully saved, false otherwise.
 */
export declare const saveData: <T>(key: STORAGE_KEY, data: T, lifespan?: number) => boolean;
/**
 * Retrieves data from the browser's local storage.
 *
 * @param key The key used for previously saving the requested data.
 * @returns The data previously stored.
 */
export declare const loadData: <T>(key: STORAGE_KEY) => T | null;
