import { E_DEPARTURE_MODE } from '../../lib/types/directions';
import type RootStore from '../root-store';
type TAnalyticsEventPayload = {
    'not-found': never;
    'select-from-map': {
        placeIds: string[];
    };
    'select-from-category': {
        placeIds: string[];
    };
    'select-from-search-result': {
        placeIds: string[];
    };
    'select-category': {
        categoryId: string;
    };
    'get-directions': {
        mode: E_DEPARTURE_MODE;
        fromIds: string[];
        toIds: string[];
    };
    'get-search-results': {
        query: string;
    };
    'get-departure-search-results': {
        query: string;
    };
    'change-floor': {
        floorId: string;
    };
    'change-departure-mode': {
        mode: E_DEPARTURE_MODE;
    };
    'toggle-accessibility': {
        enabled: boolean;
    };
    'share-button-clicked': never;
    'open-fullscreen-gallery': {
        placeId: string;
    };
    'open-link': {
        url: string;
        placeId: string;
        type: 'website' | 'social' | 'link' | 'button';
    };
    'call-phone-number': {
        phoneNumber: string;
        placeId: string;
    };
    'click-watermark': never;
    'kiosk-mode': never;
};
export type TAnalyticsEvent = keyof TAnalyticsEventPayload;
export type TCaptureParams<E extends TAnalyticsEvent> = TAnalyticsEventPayload[E] extends never ? [E] : [E, TAnalyticsEventPayload[E]];
declare class AnalyticsStore {
    private rootStore;
    constructor(rootStore: RootStore);
    capture<E extends TAnalyticsEvent>(...args: TCaptureParams<E>): void;
}
export default AnalyticsStore;
