export interface FeatureFlagProvider {
    onFeatureFlags: (callback: () => void) => void;
    reloadFeatureFlags: () => void;
    featureFlags: {
        getFlags: () => string[];
        getFlagVariants: () => Record<string, string | boolean>;
        getFlagPayloads: () => Record<string, unknown>;
    };
}
export declare enum E_FEATURE_FLAGS {
    MAKER_POP_UP = "maker-pop-up",
    PREPROCESS_IMAGE_LABELS = "preprocess-image-labels",
    HALLOWEEN_MODE = "halloween-mode",
    WINTER_MODE = "winter-mode",
    AUTH_URL = "auth-url",
    MULTI_FLOOR_VIEW = "multi-floor-view",
    SAFETY_MODE = "safety-mode",
    SIMILAR_PLACES_TOAST = "similar-places-toast"
}
type TFeatureFlagPayloads = {
    [E_FEATURE_FLAGS.MAKER_POP_UP]: boolean;
    [E_FEATURE_FLAGS.PREPROCESS_IMAGE_LABELS]: boolean;
    [E_FEATURE_FLAGS.HALLOWEEN_MODE]: boolean;
    [E_FEATURE_FLAGS.WINTER_MODE]: boolean;
    [E_FEATURE_FLAGS.AUTH_URL]: string[];
    [E_FEATURE_FLAGS.MULTI_FLOOR_VIEW]: boolean;
    [E_FEATURE_FLAGS.SAFETY_MODE]: boolean;
    [E_FEATURE_FLAGS.SIMILAR_PLACES_TOAST]: boolean;
};
type TFeatureFlag<Key extends E_FEATURE_FLAGS> = {
    /**
     * The key of the feature flag, the same value used in the Posthog UI.
     */
    key: Key;
    /**
     * The variant or value of the feature flag. By default, feature flags are
     * boolean properties, so the `variant` will be boolean, reflecting if it is
     * on or off. If the feature flag is a multivariate flag, the `variant` will
     * be a string corresponding to one of the options set in Posthog.
     */
    variant: string | boolean;
    /**
     * Feature flags can also attach a payload along with the flag. We don't have
     * any idea what type it'll be so you will need to validate the contents
     * yourself.
     */
    payload: TFeatureFlagPayloads[Key];
};
export type TFeatureFlags = {
    [key in E_FEATURE_FLAGS]: TFeatureFlag<key>;
};
declare class FeatureFlagStore {
    private timeout;
    initialized: boolean;
    flags: TFeatureFlags;
    constructor();
    private updateFeatureFlags;
    init(): Promise<unknown>;
}
export default FeatureFlagStore;
