import type RootStore from '../../root-store';
import type MapStore from '..';
import { CameraTransform, Floor, IFocusable, Place, TCameraAnimationOptions, TFocusOnOptions } from '../../../lib/sdk';
export declare const ZOOM_FACTOR = 1.025;
export declare const TILT_FACTOR = 1.05;
export declare const PAN_FACTOR = 200;
export declare const FLOOR_CHANGE_CAMERA_DELAY_MS: number;
export declare const DIRECTIONS_CAMERA_DELAY_MS: number;
export declare const FLOOR_HEIGHT = 5;
export declare const CAMERA_ANIMATION_OPTIONS: TCameraAnimationOptions;
export declare const FOCUS_ON_DEBOUNCE_MS = 250;
type TPadding = {
    top: number;
    right: number;
    bottom: number;
    left: number;
};
declare class CameraController {
    private rootStore;
    private mapStore;
    private reactionDisposers;
    private cameraChangeTimeout;
    private cameraMovingStartTime;
    /**
     * The camera transform that shows the map in it's default state.
     */
    private defaultCameraByFloorId;
    /**
     * Some additional padding that can be set from the outside (i.e. self-serve editor) to affect how the camera moves.
     * It is added the default padding in every state.
     */
    private externalPadding;
    /**
     * The camera state as an observable. This does not get updated as frequently as mapView.Camera for performance
     * reasons.
     */
    private debouncedCameraState;
    isUserInteracting: boolean;
    constructor({ rootStore, mapStore }: {
        rootStore: RootStore;
        mapStore: MapStore;
    });
    private getPadding;
    private getCoordinateFromScreenCenter;
    private handleKeyDown;
    private updateDefaultCameraForFloor;
    private updateCameraState;
    private handleCameraChange;
    private handleUserInteractionStart;
    private handleUserInteractionEnd;
    get defaultZoom(): number;
    get defaultOutdoorZoom(): number;
    get state(): CameraTransform;
    get zoomBreakpoints(): {
        labels: number;
        markers: number;
        areas: number;
        facades: number;
    };
    /**
     * Whether the camera is in the default state, i.e. the state after {@link resetZoom} is called. This will
     * return true as long as the current state is roughly equal to the default state.
     */
    get isCameraReset(): boolean;
    isCameraMoving(): boolean;
    getCameraMovementDuration(): number;
    setExternalPadding(padding: Partial<TPadding> | undefined): void;
    focusOn: (targets: Place | Floor | Place[] | IFocusable | IFocusable[], options?: TFocusOnOptions | undefined) => Promise<void>;
    zoomIn(): Promise<void>;
    zoomOut(): Promise<void>;
    panLeft(): Promise<void>;
    panRight(): Promise<void>;
    panUp(): Promise<void>;
    panDown(): Promise<void>;
    resetZoom(resetRotation?: boolean): Promise<void>;
    tiltCamera({ x, y }: {
        x: number;
        y: number;
    }): void;
    private updateCameraElevation;
    /**
     * Refocus the camera on the current floor. This function will figure out whether to focus on a place
     * or path. Optionally, you can pass in `resetZoom` to reset the zoom if there is nothing to focus.
     */
    private refocusCamera;
    cleanup(): void;
}
export default CameraController;
