import type RootStore from '../root-store';
import MarkersController from './controllers/markers';
import { E_MAP_INTERACTION_MODE } from '../../lib/types/map';
import GeometriesController from './controllers/geometries';
import DirectionsController from './controllers/directions';
import CameraController from './controllers/camera';
import LabelsController from './controllers/labels';
import HoverController from './controllers/hover';
import { MapView } from '../../lib/sdk';
import EventsController from './controllers/events';
export declare const ATTRIBUTION_MARGIN = 20;
declare class MapStore {
    private rootStore;
    private reactionDisposers;
    /**
     * It's much safer to use {@link MapStore.mapView} instead of this, as the latter is
     * only available after all the initialization logic has completed. Only read this when
     * necessary, usually to access the Map View _during_ the initialization logic.
     */
    __mv: MapView | null;
    container: HTMLElement | null;
    outdoorViewTimedOut: boolean;
    outdoorViewLoaded: boolean;
    renderFailed: boolean;
    isKeyboardFocused: boolean;
    mapViewReady: boolean;
    events: EventsController;
    markers: MarkersController;
    geometries: GeometriesController;
    directions: DirectionsController;
    camera: CameraController;
    labels: LabelsController;
    hover: HoverController;
    constructor({ rootStore }: {
        rootStore: RootStore;
    });
    private syncMapStylesWithTheme;
    private updateCurrentFloor;
    private getWatermarkOptions;
    private setOutdoorViewLoaded;
    get mapView(): Omit<MapView, 'on' | 'off'> | null;
    get interactionMode(): E_MAP_INTERACTION_MODE;
    get multiFloorViewEnabled(): boolean;
    get initialized(): boolean;
    init(container: HTMLElement): Promise<void>;
    onContainerFocus(): void;
    onContainerBlur(): void;
    cleanup(): void;
}
export default MapStore;
