import type RootStore from '../root-store';
import { TCategory, TSearchResult } from 'lib/types/search';
import { TTheme, TThemeOverride } from 'lib/types/theme';
import { E_DEPARTURE_MODE } from '../../lib/types/directions';
import { TGetDisplayNameForPlaceOptions } from '../../lib/utils/data-utils';
import { Coordinate, Place } from '../../lib/sdk';
import { TContextMenuItemEntry } from '../../components/context-menu';
import { TOnClickOrPressPayload } from '../../components/button';
import { TLevelSelectorLevel } from '../../components/level-selector/utils';
import LocationCardStore from './location-card-store';
declare class UIStore {
    private rootStore;
    private reactionDisposers;
    private makerPopUpDismissed;
    private searchBarFocusTimeout?;
    private themeBase;
    locationCardStore: LocationCardStore;
    reactiveToasts: {
        cleanup: () => void;
    }[];
    searchQuery: string;
    departureSearchQuery: string;
    droppedPinNotificationVisible: boolean;
    darkModeEnabled: boolean;
    constructor({ rootStore, theme }: {
        rootStore: RootStore;
        theme: TTheme;
    });
    private handleEscapeKey;
    private handleDocumentKeyDown;
    private share;
    private syncSearchQueryWithSelectedPlaces;
    private syncDepartureSearchQueryWithDepartureLocation;
    private syncDroppedPinNotification;
    get rootClassNames(): string;
    get theme(): TTheme & Partial<{
        name: string;
        isDark: Partial<boolean>;
        colors: Partial<{
            accent: Partial<{
                primary: string;
                secondary: string;
                neutral: string;
                neutral2: string;
                success: string;
                error: string;
            }>;
            background: Partial<{
                primary: string;
                secondary: string;
                tertiary: string;
                inverted: string;
            }>;
            text: Partial<{
                primary: string;
                secondary: string;
                tertiary: string;
                quaternary: string;
                highlight: string;
                placeholder: string;
                inverted: string;
                link: string;
                error: string;
                error2: string;
            }>;
            map: Partial<{
                labels: Partial<{
                    background: string;
                    default: string;
                    connection: string;
                    washroom: string;
                    parking: string;
                    point: string;
                    door: string;
                }>;
                markers: Partial<{
                    text: string;
                    icon: string;
                    background: string;
                    default: string;
                    parachute: string;
                    highlight: string;
                    departure: string;
                    destination: string;
                    youAreHere: string;
                }>;
                geometry: Partial<{
                    wallTops: string;
                    departure: string;
                    hover: string;
                    highlight: string;
                }>;
                path: string;
                background: string;
            }>;
        }>;
        font: string;
        borderRadius: Partial<{
            primary: number;
            large: number;
            small: number;
        }>;
        fontSize: Partial<{
            xsmall: number;
            small: number;
            normal: number;
            large: number;
            xlarge: number;
            title: number;
        }>;
        fontWeight: Partial<{
            light: number;
            normal: number;
            medium: number;
            semiBold: number;
            bold: number;
        }>;
        map: Partial<{
            tiles: string;
            initialPitch: number;
            initialBearing: number;
            minZoom: number;
            maxZoom: number;
            pathSize: number;
            streetMapVisible: Partial<boolean>;
            watermarkVisible: Partial<boolean>;
            mvfOverrides: Partial<{
                [x: string]: Partial<{
                    color: string;
                }>;
            }>;
        }>;
    }>;
    get themeId(): string;
    get allSearchResults(): TSearchResult[];
    get searchResults(): TSearchResult[];
    get departureSearchResults(): TSearchResult[];
    get searchCategories(): TCategory[];
    get levelSelectorBuildings(): {
        id: string;
        name: string;
    }[];
    get levelSelectorFloors(): Record<string, TLevelSelectorLevel[]>;
    get levelSelectorVisible(): boolean;
    get directionsButtonVisible(): boolean;
    get directionsButtonDisabled(): boolean;
    get directionsUIVisible(): boolean;
    get directionsWarning(): "directions.not-found" | "directions.adjacent" | undefined;
    get openAppLink(): string;
    get openAppButtonVisible(): boolean;
    get tiltControlsVisible(): boolean;
    get zoomControlsVisible(): boolean;
    get shareButtonVisible(): boolean;
    get mainUIVisible(): boolean;
    get mainUIMaxHeight(): number;
    get appPadding(): 0 | 10 | 20 | 15;
    get makerPopUpVisible(): boolean;
    get metadataCardVisible(): boolean;
    get availableDepartureModes(): E_DEPARTURE_MODE[];
    get accessibilityToggleVisible(): boolean;
    get safetyButtonVisible(): boolean;
    get timeoutModalEnabled(): boolean;
    get contextMenuItems(): TContextMenuItemEntry[];
    setTheme(theme: TThemeOverride): void;
    dismissMakerPopUp(): void;
    setSearchQuery(query: string): void;
    setDepartureSearchQuery(query: string): void;
    handleMainUIBlur(): void;
    handleSearchResultSelected(ids: string[], context: 'category' | 'search-result'): void;
    handleCategorySelected(id: string): void;
    handleCategoryBack(): void;
    handleDepartureSearchResultSelected(ids: string[]): void;
    handleLevelSelected(id: string): void;
    handleDirectionsButtonClick(e?: TOnClickOrPressPayload): void;
    handleDepartureModeSelected(mode: E_DEPARTURE_MODE): void;
    handleResetDepartureClick(): void;
    handleSwapDirectionsClick(): void;
    handleMetadataCardClose(): void;
    hideDroppedPinNotification(): void;
    /**
     * Given one or more {@link Place}s, return a name that is suitable for display in the UI.
     */
    getDisplayName(place: Place[]): string;
    getDisplayName(place: Place, options?: TGetDisplayNameForPlaceOptions & {
        coordinate?: Coordinate;
        preferLocationName?: boolean;
    }): string;
    handleShareClick(): boolean | void;
    handleAppTimeout(): void;
    cleanup(): void;
}
export default UIStore;
