import { Place, PlaceTypeString } from '../lib/sdk';
import { TMapViewWithTestUtilities } from './test-mocks';
import { testWithMap, TTestWithMapOptions } from './test-with-map';
type TTestPlaceTypeCallback<P extends Place = Place> = (test: Awaited<ReturnType<typeof testWithMap<TMapViewWithTestUtilities>>>, places: P[], type: PlaceTypeString) => void;
/**
 * Options for testing all place types.
 */
type TTestPlaceTypeOptions<P extends Place = Place> = Partial<{
    /**
     * The name of the fixture to use for the test.
     */
    fixture: string;
    /**
     * Options to pass to {@link testWithMap}.
     */
    testWithMapOptions: TTestWithMapOptions | ((type: PlaceTypeString) => TTestWithMapOptions);
    /**
     * Limit the test for places on the current floor.
     */
    limitPlacesToCurrentFloor: boolean;
    /**
     * By default, the callback will be passed all places of a given type. Specify a predicate to
     * filter the places to test.
     */
    filter: (place: P) => boolean;
    /**
     * If specified, the test will only be run for the given types. This overrides {@link exclude}.
     */
    only: PlaceTypeString[];
    /**
     * If specified, the test will not be run for the given types. This is overridden by {@link only}.
     */
    exclude: PlaceTypeString[];
}>;
export declare const runTest: <P extends Place = Place>(type: PlaceTypeString, cb: TTestPlaceTypeCallback<P>, options?: TTestPlaceTypeOptions<P>) => Promise<void>;
/**
 * Run a test suite by executing a test function for all types that a {@link Place} could be.
 */
declare const testPlaceTypes: {
    <P extends Place = Place>(name: string, cb: TTestPlaceTypeCallback<P>, options?: TTestPlaceTypeOptions<P>): void;
    only: <P extends Place = Place>(name: string, cb: TTestPlaceTypeCallback<P>, options?: TTestPlaceTypeOptions<P>) => void;
};
export default testPlaceTypes;
