/**
 * A set of given and expected values for testing.
 */
export type TTestCondition<Given, Expected> = readonly [Given, Expected];
/**
 * A test case with a name and a {@link TTestCondition}s.
 */
export type TTestCase<Given, Expected> = [string, readonly TTestCondition<Given, Expected>[]];
/**
 * A suite of {@link TTestCase}s.
 */
export type TTestSuite<Given, Expected> = readonly TTestCase<Given, Expected>[];
/**
 * A callback for running tests in a {@link TTestSuite}.
 */
export type TTestSuiteCallback<Given, Expected> = (testName: string, value: TTestCondition<Given, Expected>) => void;
/**
 * Run a callback with tests for each {@link TTestCase} in a {@link TTestSuite}. This is useful for
 * running many tests with the same exact format, where the input and output can be easily abstracted.
 */
declare const testSuite: {
    <Given, Expected>(name: string, config: TTestSuite<Given, Expected>, cb: TTestSuiteCallback<Given, Expected>): void;
    only: <Given, Expected>(name: string, config: TTestSuite<Given, Expected>, cb: TTestSuiteCallback<Given, Expected>) => void;
};
export default testSuite;
