import { defineConfig, devices } from '@playwright/test';
import dotenv from 'dotenv';
import path from 'path';
import url from 'url';

// Node.js modules don't have __dirname or __filename
const __filename = url.fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);
dotenv.config({ path: path.resolve(__dirname, '../.env') });

const APP_PORT = process.env.PORT || 5173;

/**
 * See https://playwright.dev/docs/test-configuration.
 */
export default defineConfig({
	testDir: '.',
	/* Run tests in files in parallel */
	fullyParallel: true,
	/* Fail the build on CI if you accidentally left test.only in the source code. */
	forbidOnly: !!process.env.CI,
	/* Retry on CI only */
	retries: process.env.CI ? 2 : 0,
	/* Opt out of parallel tests on CI. */
	workers: process.env.CI ? 1 : undefined,
	outputDir: '../../../coverage/viewer-playwright',
	/* Reporter to use. See https://playwright.dev/docs/test-reporters */
	reporter: [['json', { outputFile: '../../coverage/viewer-playwright/report.json' }]],
	/* Shared settings for all the projects below. See https://playwright.dev/docs/api/class-testoptions. */
	use: {
		/* Base URL to use in actions like `await page.goto('/')`. */
		// baseURL: 'http://127.0.0.1:3000',

		/* Collect trace when retrying the failed test. See https://playwright.dev/docs/trace-viewer */
		trace: 'on-first-retry',
	},

	/* Road labels are especially flaky, so we allow more pixels to be different */
	expect: {
		toHaveScreenshot: { maxDiffPixels: 1000 },
	},

	/* Configure projects for major browsers */
	projects: [
		{
			name: 'chromium',
			use: { ...devices['Desktop Chrome'] },
		},

		{
			name: 'firefox',
			use: { ...devices['Desktop Firefox'] },
		},

		{
			name: 'webkit',
			use: { ...devices['Desktop Safari'] },
		},

		/* Test against mobile viewports. */
		{
			name: 'Mobile Chrome',
			use: { ...devices['Pixel 5'] },
		},
		{
			name: 'Mobile Safari',
			use: { ...devices['iPhone 12'] },
		},
	],

	/* Run your local dev server before starting the tests */
	webServer: {
		command: 'pnpm dev:playwright',
		url: `http://localhost:${APP_PORT}`,
		reuseExistingServer: !process.env.CI,
	},
});
