import { Page, test } from '@playwright/test';

type TWaitForPageLoadOptions = {
	params?: Record<string, string>;
	state?: string;
	embedded?: boolean;
	featureFlags?: Record<string, unknown>;
};

export const waitForPageLoad = async (page: Page, options: TWaitForPageLoadOptions = {}) => {
	// Mock feature flags from posthog
	await page.route('https://ph-api.mappedin.com/**/*', (route) => {
		route.fulfill({
			body: JSON.stringify({
				featureFlags: options.featureFlags ?? {},
			}),
			headers: {
				'Content-Type': 'application/json',
			},
		});
	});

	const params = new URLSearchParams();
	for (const [key, value] of Object.entries(options.params ?? {})) {
		params.set(key, value.toString());
	}
	if (options.embedded) {
		params.set('embedded', 'true');
	}
	const state = options.state ?? '/';
	const url = 'http://localhost:5173/map/test-map' + state + '?' + params.toString();

	await page.goto(url);
	const spinner = page.locator('#app-loading-spinner');
	await spinner.waitFor({ state: 'visible' });
	await spinner.waitFor({ state: 'hidden' });
};

export const testDefaultAndEmbedded = (
	title: string,
	body: ({ page }: { page: Page }) => Promise<void>,
	options: TWaitForPageLoadOptions = {},
) => {
	test(title, async ({ page }) => {
		await waitForPageLoad(page, options);
		await body({ page });
	});

	test(title + ' (embedded)', async ({ page }) => {
		await waitForPageLoad(page, { ...options, embedded: true });
		await body({ page });
	});
};
